def get_tenant_access_token(tenant_id: str, app_id: str, app_secret: str) -> str:
    """
    获取应用访问令牌。

    Args:

    Returns:
        str: 应用访问令牌,用于验证应用对资源的访问权限。
    """
    pass


def get_user_access_token() -> str:
    """
    获取用户访问令牌。

    Args:

    Returns:
        str: 用户访问令牌,用于验证用户对资源的访问权限。
    """
    pass
